Admin — django-sphinxdoc 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- django-sphinxdoc 1.2.0 documentation »
- API-Reference »

# Admin

Admin interface for the sphinxdoc app.

class `sphinxdoc.admin.` `DocumentAdmin`(model, admin_site)

  Admin interface for `Document`.

  Normally, you shouldn’t need this, since you create new documents via the management command.

class `sphinxdoc.admin.` `ProjectAdmin`(model, admin_site)

  Admin interface for `Project`.

### Navigation

- index
- modules |
- next |
- previous |
- django-sphinxdoc 1.2.0 documentation »
- API-Reference »